# pyMOSF

[![rpazuki github](https://img.shields.io/badge/GitHub-rpazuki-181717.svg?style=flat&logo=github)](https://github.com/rpazuki)
[![python](https://img.shields.io/badge/Python-3.10-3776AB.svg?style=flat&logo=python&logoColor=white)](https://www.python.org)
[![License: GPLv3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)

### platforms
![iOS](https://img.shields.io/badge/macOS-999999.svg?style=flat&logo=apple)
![Ubuntu](https://img.shields.io/badge/Ubuntu-E95420?style=flat&logo=ubuntu&logoColor=white)
![iOS](https://img.shields.io/badge/iOS-999999.svg?style=flat&logo=apple)

## pyMOSF (python Multi-OF Multi-Framework)
> A lightweight python package for Multi-OS, Multi-Framework UI apps. It support [BeeWare](https://beeware.org/) and [Kivy](https://kivy.org/) frameworks.

## macOS

```
brew install cairo
brew install pyobject3

```


